translate.misc.zipfileext.ZipFileExt

Package translate :: Package misc :: Module zipfileext :: Class ZipFileExt |
[hide private]
[frames] | no frames]

# Class ZipFileExt

source code

a ZipFile that can handle replacing objects

Instance Methods | [hide private]
delete(self, name) Delete the file from the archive. | source code
close(self) Close the file, and for mode "w" and "a" write the ending records. | source code
writeendrec(self) Write the ending records (without neccessarily closing the file) | source code
Inherited from `zipfile.ZipFile`: `__del__`, `__init__`, `extract`, `extractall`, `getinfo`, `infolist`, `namelist`, `open`, `printdir`, `read`, `setpassword`, `testzip`, `write`, `writestr` Inherited from `zipfile.ZipFile` (private): `_GetContents`, `_RealGetContents`, `_extract_member`, `_writecheck` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
Inherited from `zipfile.ZipFile`: `fp`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### delete(self, name) | source code
Delete the file from the archive. If it appears multiple times only the first instance will be deleted.

### close(self) | source code
Close the file, and for mode "w" and "a" write the ending records. Overrides: zipfile.ZipFile.close